EqualityEvent
=============

.. currentmodule:: pqp.symbols

.. autoclass:: EqualityEvent
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~EqualityEvent.get_var
      ~EqualityEvent.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: get_var
   .. automethod:: to_latex
